pro sss_scale, index, minimum, maximum
; 
; - res/filter dependent scaling --??
minimum=0
maximum=5.8

return
end  

pro sxt_ssc2sss, sscfiles, outdir=outdir, outfile=outfile, $
	   refss=refss, reftest=reftest, register=register,$  
          ref_image=reg_image, regenerate=regenerate, $
          almg_norm=almg_norm, filter_norm=filter_norm, quarter_norm=quarter_norm
;+
;   Name: sxt_ssc2sss
;
;   Purpose: make a log/bytescaled version of an ssc (new prefix = sss)
;
;   Input Parameters:
;      sscfiles - list of ssc files to convert
;
;   Keyword Parameters:
;      register - if set, register including roll correction
;      ref_image - index of registration reference (def is 1st image in ssc)
;      refss - SS of desired ref_image relative to all sscfiles
;              If REFSS=-1, it will use the 'middle' image
;      reftest - just show which reference images used 
;      outdir - output directory for 'sss...' files (def = $DIR_SXT_SSS)
;      outfiles - output file names  (def is derived from ssc
;      regenerate - if set, force remake of 'sss' for all input 'ssc'files
;        [if sss exists and has same number of images as ssc, default is to
;         not remake it - use /regenerate to force]
;  
;   Calling Sequence:
;      sxt_ssc2sss, sscfiles [,outdir=outdir] [,outfile=outfile] [,/regenerate], $
;                            [ ,/register ] [, ref_image=ref_image], $
;                            [ ,/almg_norm] [, quarter_norm]
;
;   History:
;      21-April-1999 - S.L.Freeland
;      22-April-1999 - S.L.Freeland (documment)
;      11-Jan-2000   - S.L.Freeland add REFSS and /REFTEST
;       8-Aug-2000   - S.L.Freeland fix undefined variable if un-registered
;      16-May-2001   - S.L.Freeland add /AlMg_Normalize
;  
;   Restrictions:  
;      (TODO) Review res/filter dependent scaling via mini function
;             'sss_scale.pro'
;-
filter_norm=keyword_set(filter_norm) or keyword_set(almg_norm)
quarter_norm=keyword_set(quarter_norm)

break_file,sscfiles,ll,pp,ff,ee,vv
reftest=keyword_set(reftest)

defdir=get_logenv('DIR_SXT_SSS')
case 1 of
   data_chk(outdir,/string):
   defdir ne '': outdir=defdir

   else: outdir=curdir()
endcase
outdir=outdir(0)

if not file_exist(outdir) then begin
    box_message,'OUTDIR: ' + outdir + ' not found, returning...'
    return
endif

register=keyword_set(register)
; - include a "registraion" indicator in output filename
strreg=(['_nr_','_r_'])(register)
strqn=(['','_qn_'])(quarter_norm)
strfn=(['','_fn_'])(filter_norm)

case 1 of
    data_chk(outfile,/string):
    else: outfile=concat_dir(outdir,$
        str_replace(ff,'ssc','sss')+strreg+strfn+strqn+ee+vv)
endcase

case 1 of
    data_chk(ref_image,/struct):               ; user supplied
    n_elements(refss) gt 0 : begin
       if refss(0) eq -1 then begin             ; use mid
          rd_roadmap, sscfiles, rmap, ndsets
	  rd_xda, sscfiles, total(ndsets)/2, ref_image ; mid-index	  
       endif else rd_xda, sscfiles, refss, ref_image	
    endcase
    else:                                      ; 
endcase
; ------- Dont regenerate if sss exists, and nimages = ssc -----------
need=intarr(n_elements(outfile)) + keyword_set(regenerate)   ; need?
need=need or (1-file_exist(outfile))                         ; missing?
nneed=where(1-need,nncnt)                                    ; possible?
for i=0,nncnt-1 do begin             
  ssnn=nneed(i)
  rd_roadmap,sscfiles(ssnn),sscrm, sscnd
  rd_roadmap,outfile(ssnn) ,sssrm, sssnd
  ok=sscnd eq sssnd
  mess=(['SSS exists but different #img, regenerating', $
	 'SSS exists and same #img - use /REGENERATE to force update'])(ok)
  box_message,['RE:>> ' + outfile(ssnn), mess]
  need(ssnn) = 1-ok
endfor  

ssneed=where(need,nncnt)
if nncnt gt 0 then begin
   sscf=sscfiles(ssneed)
   outfile=outfile(ssneed)   
   box_message,['Need to process>>',sscf]
endif else begin
   box_message,'All SSS already generated and match SSC (use /REGEN to force update)'
   return
endelse

; ------- have the ssc->sss list --------------
for i=0,n_elements(sscf)-1 do begin                              ; each ssc
   sscfile=sscf(i)
   if file_exist(sscfile) then begin
      box_message,['Processing:>>', '   '+ sscfile, $
		   'Generating:>>', '   '+ outfile(i) ]
      if data_chk(ref_image,/struct) then $
	      refimage=ref_image else rd_xda,sscfile,0,refimage
      if reftest then box_message,['Reference image: ',$
	  get_info(refimage,/non)] else begin 
      rd_roadmap,sscfile,rmap,ndset
      for j=0,ndset-1 do begin                                   ; each image 
         rd_xda,sscfile,j,ii,dd
         sxt_ssc_rationalize,ii,dd,oii,odd,/eight,outsize=528, $
              almg_norm=filter_norm, quarter_norm=quarter_norm
	 sav_sda, outfile(i), oii, odd, append=(j ne 0)
      endfor     
      endelse
   endif else box_message,'File: ' + sscfile + ' not found...'    
endfor

return
end
