pro sxt_sss2fits, sssfiles, outsize=outsize, outres=outres, outdir=outdir, $
      prefix=prefix, yyyy=yyyy, ss=ss
;+
;   Name: sxt_ssn2fits
;
;   Purpose: convert ssc or sss files -> "Standard" FITs 
;            for export and -> YPOP/WWW movie maker
;
;   Input Parameters:
;      ssnfiles - file list to process
;  
;   Keyword Parameters:
;      outsize - size of output (for embedding, default = 576x576)
;      outres  - default = 1 (half res = ~2.54"/pix) 
;      outdir  - where to stick files
;
;   Side Effects:
;      data is registered to sun center - fits file written
;
;-

rd_roadmap,sssfiles,rmap
nim=n_elements(rmap)

if not keyword_set(outres)  then outres=1
if not keyword_set(outsize) then outsize=[576,576]
if not keyword_set(prefix) then $
     pref='sss_'+strtrim(gt_filtb(rmap,/string),2) + '_'   +      $
                   strtrim(gt_shape_cmd(rmap,/x,/string),2) + '_' + $
                   strtrim(outsize(0),2) + '_' else pref=replicate(prefix,nim)


if not keyword_set(outdir) then outdir=curdir()
case 1 of 
    keyword_set(yyyy): $
        odir=concat_dir(outdir,strmid(time2file(rmap),0,4))
    else: odir=replicate(outdir,nim)
endcase

if not keyword_set(ss) then ss=lindgen(nim)

for i =0, n_elements(ss)-1 do begin 

   sxt_prep, sssfiles, i, outindex, outdata, $
      /reg, suncoord=[0,0], /sfd_cor, /roll, outres=outres, outsize=outsize

   outindex=struct2ssw(outindex)                     ; rationalize 'index'

;  --- add tags/history/comments here? ----
   mwritefits, outindex, outdata, outdir=odir(i),prefix=pref(i) ;index,data->fits

endfor

return
end
