function week_loop, sttim, entim, weekstr=weekstr, year4digit=year4digit
;+
;NAME: 
;	week_loop
;PURPOSE:
;	Given a start and end time, return a structure listing the
;	year number and week number for all weeks between the times
;INPUT:
;	sttim	- start time in any format
;	entim	- end time in any format
;Keyword Parameters:
;   WEEKSTR (output) - string of form YY_WW or YYYY_WW  
;   YEAR4DIGIT (switch) - if set, out.YEAR and WEEKSTR are 4 digit
;  
;HISTORY:
;	Written 16-Apr-92 by M.Morrison
;	 8-Feb-92 (MDM) Added code to back up a week if the start time
;			is within 90 minutes of the first day of a week
;        6-apr-99 (SLF) make it Y2K able via /year4digit
;                       add WEEKSTR output
;        9-may-00 (pgs) standardized year format in four places.
;-
qdebug = 1
;
out0 = {week_loop_str, year: fix(0), week: fix(0)}
;
st_tarr = anytim2ex(sttim)
en_tarr = anytim2ex(entim)

st_year = st_tarr(6)
if st_year lt 50 then st_year = st_year + 100 ; y2k pgs
en_year = en_tarr(6)
if en_year lt 50 then en_year = en_year + 100 ; y2k pgs
st_week = ex2week(st_tarr)
en_week = ex2week(en_tarr)
;
;--- MDM added code for the special case where the start time is within the first 90 minutes of Sunday (the data in file obs92_xx
;    could start up to 90 minutes into the first day, because of the way the data is blocked by orbit)
;    In that case, we need to back up one week and start with that file.  Also applies to 1-Jan-xx (1+1 = 2)
st_dow = ex2dow(st_tarr)
dummy = anytim2ints(st_tarr)
if ( ((st_dow eq 0) or (st_tarr(4)+st_tarr(5) eq 2)) and (dummy.time/1000. le 100*60.)) then begin
    st_week = st_week - 1
    if (st_week lt 1) then begin
	st_week = 53
	st_year = st_year - 1
    end
end
;
en_week1 = 53
if (st_year eq en_year) then en_week1 = en_week
n = (en_week1 - st_week + 1)
out = replicate(out0, n)
out.year = st_year
if (n eq 1) then out.week = st_week else out.week = indgen(n) + st_week
;
for i=st_year+1, en_year-1 do begin
    out_tmp = replicate(out0, 53)
    out_tmp.year = i
    case 1 of 
       i ge 1900: out_tmp.year = out_tmp.year - 1900 ; y2k pgs
       i ge 100:  out_tmp.year = out_tmp.year - 100
       else:
    endcase
    out_tmp.week = indgen(53)+1
    out = [out, out_tmp]
end
if (st_year ne en_year) then begin
    out_tmp = replicate(out0, en_week)
    out_tmp.year = en_year
    case 1 of
       en_year ge 1900: out_tmp.year = out_tmp.year - 1900
       en_year ge 100: out_tmp.year =out_tmp.year -100
       else:
    endcase
    out_tmp.week = 1
    if (en_week ne 1) then out_tmp.week = indgen(en_week)+1
    out = [out, out_tmp]
end

year4digit=keyword_set(year4digit)

if keyword_set(year4digit) then begin
   out.year=out.year+([1900,2000])(out.year lt 50)
endif
stop

fmt=(['(i2.2)','(i4.4)'])(year4digit)
weekstr=fstring(out.year,format=fmt) + '_' + fstring(out.week,format='(i2.2)')

return, out
end
